#[repr(u8)]pub enum Lps {
NOT_PRGRMD_IN_SECURE_OR_TRUSTED_STATE = 0,
WAS_PRGRMD_IN_SECURE_OR_TRUSTED_STATE = 1,
}Variants
NOT_PRGRMD_IN_SECURE_OR_TRUSTED_STATE = 0
LP section was not programmed in secure or trusted state.
WAS_PRGRMD_IN_SECURE_OR_TRUSTED_STATE = 1
LP section was programmed in secure or trusted state.
Implementations