#[repr(u8)]pub enum PiFreq {
Show 16 variants
USE_BIT_0 = 0,
USE_BIT_1 = 1,
USE_BIT_2 = 2,
USE_BIT_3 = 3,
USE_BIT_4 = 4,
USE_BIT_5 = 5,
USE_BIT_6 = 6,
USE_BIT_7 = 7,
USE_BIT_8 = 8,
USE_BIT_9 = 9,
USE_BIT_10 = 10,
USE_BIT_11 = 11,
USE_BIT_12 = 12,
USE_BIT_13 = 13,
USE_BIT_14 = 14,
USE_BIT_1R5 = 15,
}Variants
USE_BIT_0 = 0
- bit 0 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_1 = 1
- bit 1 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_2 = 2
- bit 2 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_3 = 3
- bit 3 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_4 = 4
- bit 4 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_5 = 5
- bit 5 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_6 = 6
- bit 6 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_7 = 7
- bit 7 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_8 = 8
- bit 8 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_9 = 9
- bit 9 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_10 = 10
- bit 10 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_11 = 11
- bit 11 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_12 = 12
- bit 12 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_13 = 13
- bit 13 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_14 = 14
- bit 14 of the HPRTCLR is selected as a source of the periodic interrupt
USE_BIT_1R5 = 15
- bit 15 of the HPRTCLR is selected as a source of the periodic interrupt
Implementations