#[repr(u8)]pub enum SrtcInvEn {
KEEP_VALID = 0,
INVALIDATE = 1,
}Variants
KEEP_VALID = 0
SRTC stays valid in the case of security violation (other than a software violation (HPSVSR[SW_LPSV] = 1 or HPCOMR[SW_LPSV] = 1)).
INVALIDATE = 1
SRTC is invalidated in the case of security violation.
Implementations